# ServiceX Client Library


[![GitHub Actions Status](https://github.com/ssl-hep/ServiceX_frontend/actions/workflows/ci.yaml/badge.svg)](https://github.com/ssl-hep/ServiceX_frontend/actions/workflows/ci.yaml?query=branch%3Amaster)
[![Code Coverage](https://codecov.io/gh/ssl-hep/ServiceX_frontend/graph/badge.svg)](https://codecov.io/gh/ssl-hep/ServiceX_frontend)

[![PyPI version](https://badge.fury.io/py/servicex.svg)](https://badge.fury.io/py/servicex)
[![conda-forge version](https://img.shields.io/conda/vn/conda-forge/servicex.svg)](https://github.com/conda-forge/servicex-feedstock.git)
[![Supported Python versions](https://img.shields.io/pypi/pyversions/servicex.svg)](https://pypi.org/project/servicex/)

[![Docs](https://readthedocs.org/projects/docs/badge/?version=latest)](https://servicex-frontend.readthedocs.io)


Python SDK and CLI Client for ServiceX

## Documentation

* The **user** documentation is hosted at https://servicex-frontend.readthedocs.io
* The **developer** documentation is available under the [`latest` view](https://servicex-frontend.readthedocs.io/en/latest/)
